tiny-parsec

command module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2025 License: MIT Imports: 2 Imported by: 0

README

Tiny Parsec

A parser combinator library inspired by Haskell's Parsec, implemented in Go with strong type safety.

Features

  • Type-safe parser combinators
  • JSON parser implementation
  • Immutable parser state
  • Comprehensive combinator library
  • Error handling with parser state tracking

Installation

go get github.com/81120/tiny-parsec

Quick Start

package main

import (
	"fmt"
	"github.com/81120/tiny-parsec/parser"
)

func main() {
	p := parser.Trim(parser.Char('a'))
	result := p.Parse(" a ")
	fmt.Println(result) // Just('a')
}

Documentation

The Go Gopher

There is no documentation for this package.

Directories

Path Synopsis
Package json defines a set of types to represent JSON data in Go.
Package json defines a set of types to represent JSON data in Go.
Package parser provides a set of combinators for building parsers in Go.
Package parser provides a set of combinators for building parsers in Go.

Jump to