command
module
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Mar 22, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Tiny Parsec
A parser combinator library inspired by Haskell's Parsec, implemented in Go with strong type safety.
Features
- Type-safe parser combinators
- JSON parser implementation
- Immutable parser state
- Comprehensive combinator library
- Error handling with parser state tracking
Installation
go get github.com/81120/tiny-parsec
Quick Start
package main
import (
"fmt"
"github.com/81120/tiny-parsec/parser"
)
func main() {
p := parser.Trim(parser.Char('a'))
result := p.Parse(" a ")
fmt.Println(result) // Just('a')
}
Documentation
¶
There is no documentation for this package.
Source Files
¶
Directories
¶
Package json defines a set of types to represent JSON data in Go.
|
Package json defines a set of types to represent JSON data in Go. |
Package parser provides a set of combinators for building parsers in Go.
|
Package parser provides a set of combinators for building parsers in Go. |
Click to show internal directories.
Click to hide internal directories.